==> openshift-model-installer-6.7.2-sources.jar: io/fabric8/openshift/api/model/installer/vsphere/v1/PlatformBuilder.java <==
package io.fabric8.openshift.api.model.installer.vsphere.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PlatformBuilder extends PlatformFluentImpl<PlatformBuilder> implements VisitableBuilder<Platform,PlatformBuilder>{
  public PlatformBuilder() {
    this(false);
  }
  public PlatformBuilder(Boolean validationEnabled) {
    this(new Platform(), validationEnabled);
  }
  public PlatformBuilder(PlatformFluent<?> fluent) {
    this(fluent, false);
  }
  public PlatformBuilder(PlatformFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Platform(), validationEnabled);
  }
  public PlatformBuilder(PlatformFluent<?> fluent,Platform instance) {
    this(fluent, instance, false);
  }
  public PlatformBuilder(PlatformFluent<?> fluent,Platform instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVIP(instance.getApiVIP());
      fluent.withCluster(instance.getCluster());
      fluent.withClusterOSImage(instance.getClusterOSImage());
      fluent.withDatacenter(instance.getDatacenter());
      fluent.withDefaultDatastore(instance.getDefaultDatastore());
      fluent.withDefaultMachinePlatform(instance.getDefaultMachinePlatform());
      fluent.withDiskType(instance.getDiskType());
      fluent.withFolder(instance.getFolder());
      fluent.withIngressVIP(instance.getIngressVIP());
      fluent.withNetwork(instance.getNetwork());
      fluent.withPassword(instance.getPassword());
      fluent.withResourcePool(instance.getResourcePool());
      fluent.withUsername(instance.getUsername());
      fluent.withVCenter(instance.getVCenter());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PlatformBuilder(Platform instance) {
    this(instance,false);
  }
  public PlatformBuilder(Platform instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVIP(instance.getApiVIP());
      this.withCluster(instance.getCluster());
      this.withClusterOSImage(instance.getClusterOSImage());
      this.withDatacenter(instance.getDatacenter());
      this.withDefaultDatastore(instance.getDefaultDatastore());
      this.withDefaultMachinePlatform(instance.getDefaultMachinePlatform());
      this.withDiskType(instance.getDiskType());
      this.withFolder(instance.getFolder());
      this.withIngressVIP(instance.getIngressVIP());
      this.withNetwork(instance.getNetwork());
      this.withPassword(instance.getPassword());
      this.withResourcePool(instance.getResourcePool());
      this.withUsername(instance.getUsername());
      this.withVCenter(instance.getVCenter());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PlatformFluent<?> fluent;
  Boolean validationEnabled;
  public Platform build() {
    Platform buildable = new Platform(fluent.getApiVIP(),fluent.getCluster(),fluent.getClusterOSImage(),fluent.getDatacenter(),fluent.getDefaultDatastore(),fluent.getDefaultMachinePlatform(),fluent.getDiskType(),fluent.getFolder(),fluent.getIngressVIP(),fluent.getNetwork(),fluent.getPassword(),fluent.getResourcePool(),fluent.getUsername(),fluent.getVCenter());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-installer-6.8.1-sources.jar: io/fabric8/openshift/api/model/installer/vsphere/v1/PlatformBuilder.java <==
package io.fabric8.openshift.api.model.installer.vsphere.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PlatformBuilder extends PlatformFluent<PlatformBuilder> implements VisitableBuilder<Platform,PlatformBuilder>{
  public PlatformBuilder() {
    this(false);
  }
  public PlatformBuilder(Boolean validationEnabled) {
    this(new Platform(), validationEnabled);
  }
  public PlatformBuilder(PlatformFluent<?> fluent) {
    this(fluent, false);
  }
  public PlatformBuilder(PlatformFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Platform(), validationEnabled);
  }
  public PlatformBuilder(PlatformFluent<?> fluent,Platform instance) {
    this(fluent, instance, false);
  }
  public PlatformBuilder(PlatformFluent<?> fluent,Platform instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Platform());

    if (instance != null) {
      fluent.withApiVIP(instance.getApiVIP());
      fluent.withApiVIPs(instance.getApiVIPs());
      fluent.withCluster(instance.getCluster());
      fluent.withClusterOSImage(instance.getClusterOSImage());
      fluent.withDatacenter(instance.getDatacenter());
      fluent.withDefaultDatastore(instance.getDefaultDatastore());
      fluent.withDefaultMachinePlatform(instance.getDefaultMachinePlatform());
      fluent.withDiskType(instance.getDiskType());
      fluent.withFailureDomains(instance.getFailureDomains());
      fluent.withFolder(instance.getFolder());
      fluent.withIngressVIP(instance.getIngressVIP());
      fluent.withIngressVIPs(instance.getIngressVIPs());
      fluent.withLoadBalancer(instance.getLoadBalancer());
      fluent.withNetwork(instance.getNetwork());
      fluent.withPassword(instance.getPassword());
      fluent.withResourcePool(instance.getResourcePool());
      fluent.withUsername(instance.getUsername());
      fluent.withVCenter(instance.getVCenter());
      fluent.withVcenters(instance.getVcenters());
      fluent.withApiVIP(instance.getApiVIP());
      fluent.withApiVIPs(instance.getApiVIPs());
      fluent.withCluster(instance.getCluster());
      fluent.withClusterOSImage(instance.getClusterOSImage());
      fluent.withDatacenter(instance.getDatacenter());
      fluent.withDefaultDatastore(instance.getDefaultDatastore());
      fluent.withDefaultMachinePlatform(instance.getDefaultMachinePlatform());
      fluent.withDiskType(instance.getDiskType());
      fluent.withFailureDomains(instance.getFailureDomains());
      fluent.withFolder(instance.getFolder());
      fluent.withIngressVIP(instance.getIngressVIP());
      fluent.withIngressVIPs(instance.getIngressVIPs());
      fluent.withLoadBalancer(instance.getLoadBalancer());
      fluent.withNetwork(instance.getNetwork());
      fluent.withPassword(instance.getPassword());
      fluent.withResourcePool(instance.getResourcePool());
      fluent.withUsername(instance.getUsername());
      fluent.withVCenter(instance.getVCenter());
      fluent.withVcenters(instance.getVcenters());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PlatformBuilder(Platform instance) {
    this(instance,false);
  }
  public PlatformBuilder(Platform instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Platform());

    if (instance != null) {
      this.withApiVIP(instance.getApiVIP());
      this.withApiVIPs(instance.getApiVIPs());
      this.withCluster(instance.getCluster());
      this.withClusterOSImage(instance.getClusterOSImage());
      this.withDatacenter(instance.getDatacenter());
      this.withDefaultDatastore(instance.getDefaultDatastore());
      this.withDefaultMachinePlatform(instance.getDefaultMachinePlatform());
      this.withDiskType(instance.getDiskType());
      this.withFailureDomains(instance.getFailureDomains());
      this.withFolder(instance.getFolder());
      this.withIngressVIP(instance.getIngressVIP());
      this.withIngressVIPs(instance.getIngressVIPs());
      this.withLoadBalancer(instance.getLoadBalancer());
      this.withNetwork(instance.getNetwork());
      this.withPassword(instance.getPassword());
      this.withResourcePool(instance.getResourcePool());
      this.withUsername(instance.getUsername());
      this.withVCenter(instance.getVCenter());
      this.withVcenters(instance.getVcenters());
      this.withApiVIP(instance.getApiVIP());
      this.withApiVIPs(instance.getApiVIPs());
      this.withCluster(instance.getCluster());
      this.withClusterOSImage(instance.getClusterOSImage());
      this.withDatacenter(instance.getDatacenter());
      this.withDefaultDatastore(instance.getDefaultDatastore());
      this.withDefaultMachinePlatform(instance.getDefaultMachinePlatform());
      this.withDiskType(instance.getDiskType());
      this.withFailureDomains(instance.getFailureDomains());
      this.withFolder(instance.getFolder());
      this.withIngressVIP(instance.getIngressVIP());
      this.withIngressVIPs(instance.getIngressVIPs());
      this.withLoadBalancer(instance.getLoadBalancer());
      this.withNetwork(instance.getNetwork());
      this.withPassword(instance.getPassword());
      this.withResourcePool(instance.getResourcePool());
      this.withUsername(instance.getUsername());
      this.withVCenter(instance.getVCenter());
      this.withVcenters(instance.getVcenters());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PlatformFluent<?> fluent;
  Boolean validationEnabled;
  public Platform build() {
    Platform buildable = new Platform(fluent.getApiVIP(),fluent.getApiVIPs(),fluent.getCluster(),fluent.getClusterOSImage(),fluent.getDatacenter(),fluent.getDefaultDatastore(),fluent.buildDefaultMachinePlatform(),fluent.getDiskType(),fluent.buildFailureDomains(),fluent.getFolder(),fluent.getIngressVIP(),fluent.getIngressVIPs(),fluent.getLoadBalancer(),fluent.getNetwork(),fluent.getPassword(),fluent.getResourcePool(),fluent.getUsername(),fluent.getVCenter(),fluent.buildVcenters());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
